from setuptools import setup,find_packages

setup(
    name='datacpp',
    version='0.6',
    packages=find_packages(),
    description="This is a torch data load package.",
    author="UCAS wang lishun",
    author_email="690332121@qq.com",
    url="https://github.com/wanlishun66668/datacpp",
    include_package_data=True
)